# ![](./icon.svg) deemix
## What is deemix?
deemix is a deezer downloader built from the ashes of Deezloader Remix. The base library (or core) can be used as a stand alone CLI app or implemented in an UI using the API.

## Installation
NOTE: If `python3` is "not a recognized command" try using `python` instead.<br>
<br>
### From PyPi
You can install the library by using `pip`:<br>
`python3 -m pip install deemix`<br>
If you install it this way you can use the deemix CLI by using `deemix` directly in your terminal instead of `python3 -m deemix`

### Building from source
After installing Python open a terminal/command prompt and install the dependencies using `python3 -m pip install -r requirements.txt --user`<br>
Run `python3 -m deemix --help` to see how to use the app in CLI mode.<br>

## What's left to do?
- Write the API Documentation
- Fix whatever is broken

# License
This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
